==> php82-nextcloud-26.0.5.tgz: share/nextcloud/apps/viewer/l10n/es_EC.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visor",
    "Simple file viewer with slideshow for media" : "Visor de archivos simple con presentación de diapositivas para medios",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Muestra tus últimas fotos y videos de vacaciones como en las películas, muestra un vistazo de tu última novela directamente desde tu Nextcloud, elige el mejor GIF de tu colección gracias a la vista previa directa de tus archivos favoritos ¡y mucho más!",
    "Your browser does not support audio." : "Tu navegador no admite audio.",
    "Error loading {name}" : "Error al cargar {name}",
    "Image saved" : "Imagen guardada",
    "Error saving image" : "Error al guardar la imagen",
    "Unsaved changes" : "Cambios no guardados",
    "Drop changes" : "Descartar cambios",
    "\"{fileName}\"" : "\"{fileName}\"",
    "Your browser does not support videos." : "Tu navegador no admite videos.",
    "Edit" : "Editar",
    "Exit full screen" : "Salir de pantalla completa",
    "Full screen" : "Pantalla completa",
    "Open sidebar" : "Abrir barra lateral",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "This file no longer exists" : "Este archivo ya no existe",
    "There is no plugin available to display this file type" : "No hay un complemento disponible para mostrar este tipo de archivo",
    "View" : "Ver",
    "Name" : "Nombre",
    "Save" : "Guardar",
    "Save as" : "Guardar como",
    "Back" : "Atrás",
    "Loading …" : "Loading …",
    "Reset" : "Restablecer",
    "All changes will be lost." : "Se perderán todos los cambios.",
    "Are you sure you want to continue?" : "¿Estás seguro de que deseas continuar?",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "Undo" : "Deshacer",
    "Redo" : "Rehacer",
    "Show original image" : "Mostrar imagen original",
    "Zoom in" : "Acerca",
    "Zoom out" : "Alejar",
    "Toggle zoom menu" : "Alternar menú de zoom",
    "Adjust" : "Ajustar",
    "Fine-tune" : "Ajuste fino",
    "Filters" : "Filtros",
    "Watermark" : "Marca de agua",
    "Draw" : "Dibujar",
    "Resize" : "Redimensionar",
    "Invalid image." : "Imagen no válida.",
    "Error while uploading the image." : "Error al cargar la imagen.",
    "are not images" : "no son imágenes",
    "is not an image" : "no es una imagen",
    "to be uploaded" : "para subir",
    "Crop" : "Recortar",
    "Original" : "Original",
    "Custom" : "Personalizado",
    "Square" : "Cuadrado",
    "Landscape" : "Paisaje",
    "Portrait" : "Retrato",
    "Ellipse" : "Elipse",
    "Classic TV" : "TV clásica",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Flecha",
    "Blur" : "Desenfoque",
    "Brightness" : "Brillo",
    "Contrast" : "Contraste",
    "Un-flip X" : "Desvirar X",
    "Flip X" : "Voltear X",
    "Un-flip Y" : "Desvirar Y",
    "Flip Y" : "Voltear Y",
    "HSV" : "HSV",
    "Hue" : "Tono",
    "Saturation" : "Saturación",
    "Value" : "Valor",
    "Image" : "Imagen",
    "Importing …" : "Importando ...",
    "+ Add image" : "+ Agregar imagen",
    "Line" : "Línea",
    "Pen" : "Lápiz",
    "Polygon" : "Polígono",
    "Sides" : "Lados",
    "Rectangle" : "Rectángulo",
    "Corner Radius" : "Radio de esquina",
    "Width in pixels" : "Ancho en píxeles",
    "Height in pixels" : "Alto en píxeles",
    "Toggle ratio lock" : "Alternar bloqueo de relación",
    "Reset to original image size" : "Restablecer al tamaño original de la imagen",
    "Rotate" : "Rotar",
    "Text" : "Texto",
    "Text spacing" : "Espaciado de texto",
    "Text alignment" : "Alineación de texto",
    "Font family" : "Familia de fuentes",
    "Size" : "Tamaño",
    "Letter spacing" : "Espaciado entre letras",
    "Line height" : "Altura de línea",
    "Warmth" : "Calidez",
    "+ Add watermark" : "+ Agregar marca de agua",
    "Choose watermark type" : "Elegir tipo de marca de agua",
    "Upload watermark" : "Subir marca de agua",
    "Add as text" : "Agregar como texto",
    "Padding" : "Padding",
    "Shadow" : "Sombra",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacidad",
    "Position" : "Posición",
    "Stroke" : "Trazo",
    "Save image as" : "Guardar imagen como",
    "Extension" : "Extensión",
    "Name is required." : "Se requiere el nombre.",
    "Quality" : "Calidad",
    "Saved image size (width x height)" : "Tamaño de imagen guardada (ancho x alto)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Ten en cuenta que el área de recorte seleccionada es menor que el redimensionamiento aplicado, lo que puede causar una disminución en la calidad",
    "Actual size (100%)" : "Tamaño real (100%)",
    "Fit size" : "Ajustar tamaño"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> php82-nextcloud-28.0.6.tgz: share/nextcloud/apps/viewer/l10n/es_EC.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visor",
    "Simple file viewer with slideshow for media" : "Visor de archivos simple con presentación de diapositivas para medios",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Muestra tus últimas fotos y videos de vacaciones como en las películas, muestra un vistazo de tu última novela directamente desde tu Nextcloud, elige el mejor GIF de tu colección gracias a la vista previa directa de tus archivos favoritos ¡y mucho más!",
    "Your browser does not support audio." : "Tu navegador no admite audio.",
    "Error loading {name}" : "Error al cargar {name}",
    "Image saved" : "Imagen guardada",
    "Error saving image" : "Error al guardar la imagen",
    "Unsaved changes" : "Cambios no guardados",
    "Drop changes" : "Descartar cambios",
    "Your browser does not support videos." : "Tu navegador no admite videos.",
    "Edit" : "Editar",
    "Exit full screen" : "Salir de pantalla completa",
    "Full screen" : "Pantalla completa",
    "Open sidebar" : "Abrir barra lateral",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "This file no longer exists" : "Este archivo ya no existe",
    "There is no plugin available to display this file type" : "No hay un complemento disponible para mostrar este tipo de archivo",
    "View" : "Ver",
    "Name" : "Nombre",
    "Save" : "Guardar",
    "Save as" : "Guardar como",
    "Back" : "Atrás",
    "Loading …" : "Loading …",
    "Reset" : "Restablecer",
    "All changes will be lost." : "Se perderán todos los cambios.",
    "Are you sure you want to continue?" : "¿Estás seguro de que deseas continuar?",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "Undo" : "Deshacer",
    "Redo" : "Rehacer",
    "Show original image" : "Mostrar imagen original",
    "Zoom in" : "Acerca",
    "Zoom out" : "Alejar",
    "Toggle zoom menu" : "Alternar menú de zoom",
    "Adjust" : "Ajustar",
    "Fine-tune" : "Ajuste fino",
    "Filters" : "Filtros",
    "Watermark" : "Marca de agua",
    "Draw" : "Dibujar",
    "Resize" : "Redimensionar",
    "Invalid image." : "Imagen no válida.",
    "Error while uploading the image." : "Error al cargar la imagen.",
    "are not images" : "no son imágenes",
    "is not an image" : "no es una imagen",
    "to be uploaded" : "para subir",
    "Crop" : "Recortar",
    "Original" : "Original",
    "Custom" : "Personalizado",
    "Square" : "Cuadrado",
    "Landscape" : "Paisaje",
    "Portrait" : "Retrato",
    "Ellipse" : "Elipse",
    "Classic TV" : "TV clásica",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Flecha",
    "Blur" : "Desenfoque",
    "Brightness" : "Brillo",
    "Contrast" : "Contraste",
    "Un-flip X" : "Desvirar X",
    "Flip X" : "Voltear X",
    "Un-flip Y" : "Desvirar Y",
    "Flip Y" : "Voltear Y",
    "HSV" : "HSV",
    "Hue" : "Tono",
    "Saturation" : "Saturación",
    "Value" : "Valor",
    "Image" : "Imagen",
    "Importing …" : "Importando ...",
    "+ Add image" : "+ Agregar imagen",
    "Line" : "Línea",
    "Pen" : "Lápiz",
    "Polygon" : "Polígono",
    "Sides" : "Lados",
    "Rectangle" : "Rectángulo",
    "Corner Radius" : "Radio de esquina",
    "Width in pixels" : "Ancho en píxeles",
    "Height in pixels" : "Alto en píxeles",
    "Toggle ratio lock" : "Alternar bloqueo de relación",
    "Reset to original image size" : "Restablecer al tamaño original de la imagen",
    "Rotate" : "Rotar",
    "Text" : "Texto",
    "Text spacing" : "Espaciado de texto",
    "Text alignment" : "Alineación de texto",
    "Font family" : "Familia de fuentes",
    "Size" : "Tamaño",
    "Letter spacing" : "Espaciado entre letras",
    "Line height" : "Altura de línea",
    "Warmth" : "Calidez",
    "+ Add watermark" : "+ Agregar marca de agua",
    "Choose watermark type" : "Elegir tipo de marca de agua",
    "Upload watermark" : "Subir marca de agua",
    "Add as text" : "Agregar como texto",
    "Padding" : "Padding",
    "Shadow" : "Sombra",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacidad",
    "Position" : "Posición",
    "Stroke" : "Trazo",
    "Save image as" : "Guardar imagen como",
    "Extension" : "Extensión",
    "Name is required." : "Se requiere el nombre.",
    "Quality" : "Calidad",
    "Saved image size (width x height)" : "Tamaño de imagen guardada (ancho x alto)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Ten en cuenta que el área de recorte seleccionada es menor que el redimensionamiento aplicado, lo que puede causar una disminución en la calidad",
    "Actual size (100%)" : "Tamaño real (100%)",
    "Fit size" : "Ajustar tamaño",
    "\"{fileName}\"" : "\"{fileName}\""
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
